@@ -96,11 +96,11 @@ Attachment AttachmentHandler::find(const QString &attachmentName, const Incidenc
     }
 
     if (a.isUri()) {
-        auto job = KIO::statDetails(QUrl(a.uri()), KIO::StatJob::SourceSide, KIO::StatBasic);
+        auto job = KIO::stat(QUrl(a.uri()), KIO::StatJob::SourceSide, KIO::StatBasic);
 
         KJobWidgets::setWindow(job, d->mParent);
         if (!job->exec()) {
-            KMessageBox::sorry(
+            KMessageBox::error(
                 d->mParent,
                 i18n("The attachment \"%1\" is a web link that is inaccessible from this computer. ", QUrl::fromPercentEncoding(a.uri().toLatin1())));
             return Attachment();
@@ -304,3 +304,5 @@ void AttachmentHandler::slotFinishView(KJob *job)
     d->mJobToReceivedInfo.remove(job);
 }
 } // namespace CalendarSupport
+
+#include "moc_attachmenthandler.cpp"
