@@ -10,11 +10,11 @@
 #include "journalprint.h"
 #include "yearprint.h"
 
+#include <KConfigGroup>
 #include <KMessageBox>
 #include <KStandardGuiItem>
-#include <QVBoxLayout>
+#include <KWindowStateSaver>
 
-#include <KConfigGroup>
 #include <QButtonGroup>
 #include <QDialogButtonBox>
 #include <QGridLayout>
@@ -23,18 +23,16 @@
 #include <QPrintPreviewDialog>
 #include <QSplitter>
 #include <QStackedWidget>
-
-#include <PimCommon/KPimPrintPreviewDialog>
+#include <QVBoxLayout>
 
 using namespace CalendarSupport;
 
-CalPrinter::CalPrinter(QWidget *parent, const Akonadi::ETMCalendar::Ptr &calendar, bool uniqItem)
+CalPrinter::CalPrinter(QWidget *parent, const KCalendarCore::Calendar::Ptr &calendar, bool uniqItem)
     : QObject(parent)
     , mParent(parent)
     , mConfig(new KConfig(QStringLiteral("calendar_printing.rc"), KConfig::SimpleConfig))
     , mUniqItem(uniqItem)
 {
-
     init(calendar);
 }
 
@@ -44,7 +42,7 @@ CalPrinter::~CalPrinter()
     delete mConfig;
 }
 
-void CalPrinter::init(const Akonadi::ETMCalendar::Ptr &calendar)
+void CalPrinter::init(const KCalendarCore::Calendar::Ptr &calendar)
 {
     mCalendar = calendar;
 
@@ -88,7 +86,7 @@ void CalPrinter::print(int type, QDate fd, QDate td, const KCalendarCore::Incide
     }
     QPointer<CalPrintDialog> printDialog = new CalPrintDialog(type, mPrintPlugins, mParent, mUniqItem);
 
-    KConfigGroup grp(mConfig, ""); // orientation setting isn't in a group
+    KConfigGroup grp(mConfig, QStringLiteral("")); // orientation setting isn't in a group
     printDialog->setOrientation(CalPrinter::ePrintOrientation(grp.readEntry("Orientation", 1)));
     printDialog->setPreview(preview);
     setDateRange(fd, td);
@@ -132,7 +130,8 @@ void CalPrinter::doPrint(PrintPlugin *selectedStyle, CalPrinter::ePrintOrientati
     }
 
     if (preview) {
-        QPointer<PimCommon::KPimPrintPreviewDialog> printPreview = new PimCommon::KPimPrintPreviewDialog(&printer);
+        QPointer<QPrintPreviewDialog> printPreview = new QPrintPreviewDialog(&printer);
+        new KWindowStateSaver(printPreview.data(), QLatin1String("CalendarPrintPreviewDialog"));
         connect(printPreview.data(), &QPrintPreviewDialog::paintRequested, this, [selectedStyle, &printer]() {
             selectedStyle->doPrint(&printer);
         });
@@ -309,3 +308,5 @@ void CalPrintDialog::slotOk()
     }
     accept();
 }
+
+#include "moc_calprinter.cpp"
